/***********************************************************************************************************************
 *
 * blueBill Stats
 * Copyright (C) 2011-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluebill.tidalwave.it/mobile/
 * SCM: http://java.net/hg/bluebill-server~stats-src
 *
 **********************************************************************************************************************/
package it.tidalwave.role.ui;

import javax.annotation.Nonnull;

/***********************************************************************************************************************
 *
 * A factory of {@link PresentationModel}s.
 * 
 * @stereotype Factory
 * 
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public interface PresentationModelFactory 
  {
    /*******************************************************************************************************************
     *
     * Creates an empty {@link PresentationModel}, that is with no wrapped object and no roles.
     * 
     * @return         the {@code PresentationModel}
     *
     ******************************************************************************************************************/
    @Nonnull
    public PresentationModel createPresentationModel();

    /*******************************************************************************************************************
     *
     * Creates a {@link PresentationModel} with no wrapped object, but with explicit roles.
     * 
     * @param  roles   the roles
     * @return         the {@code PresentationModel}
     *
     ******************************************************************************************************************/
    @Nonnull
    public PresentationModel createPresentationModel (@Nonnull Object[] roles);
    
    /*******************************************************************************************************************
     *
     * Creates a {@link PresentationModel} wrapping the given owner. This {@code PresentationModel} will feature the
     * same roles as the wrapped object.
     * 
     * @param  owner   the wrapped object
     * @return         the {@code PresentationModel}
     *
     ******************************************************************************************************************/
    @Nonnull
    public PresentationModel createPresentationModel (@Nonnull Object owner);

    /*******************************************************************************************************************
     *
     * Creates a {@link PresentationModel} wrapping the given owner and with explicit roles. This 
     * {@code PresentationModel} will feature the same roles as the wrapped object, plus the explicitly given ones.
     * 
     * @param  owner   the wrapped object
     * @param  roles   the roles
     * @return         the {@code PresentationModel}
     *
     ******************************************************************************************************************/
    @Nonnull
    public PresentationModel createPresentationModel (@Nonnull Object owner, Object[] roles);
  }
